Contribution Guidelines
=======================

Fedimg welcomes contributors of all levels. Still, it can be a tricky project
to jump into because of its relative youth and the challenge of testing a
project that utilizes 3rd party services like AWS. This document hopes to
alleviate confusion and encourage potential contributors.

Communicating with other contributors
-------------------------------------

Communication with other contributors is crucial. The best way to discuss
Fedimg development is by joining ``#fedora-cloud`` or ``#fedora-apps`` on the
Freenode IRC network. For questions about the Fedora Infrastructure machines
on which Fedimg runs, or about related fedmsg, your best bet is to say
something in ``#fedora-apps``.

You can also send an email to the `infrastructure mailing list`_.

Submitting changes
------------------

Fedimg uses `Git`_ and is hosted on `GitHub`. If you've managed to improve
Fedimg in some way, make sure to open a `pull requests`_ at
`github.com/fedora-infra/fedimg`_, or you may email a patch to the
`infrastructure mailing list`_.

.. _infrastructure mailing list: https://lists.fedoraproject.org/admin/lists/infrastructure.lists.fedoraproject.org/
.. _git: https://git-scm.com/
.. _pull requests: https://help.github.com/articles/creating-a-pull-request/
.. _github.com/fedora-infra/fedimg: https://github.com/fedora-infra/fedimg
